@@ -10,6 +10,8 @@ from pydicom.uid import ImplicitVRLittleEndian
 """
 File contains helper methods that handles DICOM header creation/formatting
 """
+
+
 def create_rtstruct_dataset(series_data) -> FileDataset:
     ds = generate_base_dataset()
     add_study_and_series_information(ds, series_data)
@@ -17,6 +19,7 @@ def create_rtstruct_dataset(series_data) -> FileDataset:
     add_refd_frame_of_ref_sequence(ds, series_data)
     return ds
 
+
 def generate_base_dataset() -> FileDataset:
     file_name = 'rt-utils-struct'
     file_meta = get_file_meta()
@@ -25,16 +28,18 @@ def generate_base_dataset() -> FileDataset:
     add_sequence_lists_to_ds(ds)
     return ds
 
+
 def get_file_meta() -> FileMetaDataset:
     file_meta = FileMetaDataset()
     file_meta.FileMetaInformationGroupLength = 202
     file_meta.FileMetaInformationVersion = b'\x00\x01'
     file_meta.TransferSyntaxUID = ImplicitVRLittleEndian
     file_meta.MediaStorageSOPClassUID = SOPClassUID.RTSTRUCT
-    file_meta.MediaStorageSOPInstanceUID = generate_uid() # TODO find out random generation is fine
+    file_meta.MediaStorageSOPInstanceUID = generate_uid()  # TODO find out random generation is fine
     file_meta.ImplementationClassUID = SOPClassUID.RTSTRUCT_IMPLEMENTATION_CLASS
     return file_meta
-    
+
+
 def add_required_elements_to_ds(ds: FileDataset):
     dt = datetime.datetime.now()
     # Append data elements required by the DICOM standarad
@@ -57,13 +62,15 @@ def add_required_elements_to_ds(ds: FileDataset):
 
     ds.ApprovalStatus = 'UNAPPROVED'
 
+
 def add_sequence_lists_to_ds(ds: FileDataset):
     ds.StructureSetROISequence = Sequence()
     ds.ROIContourSequence = Sequence()
     ds.RTROIObservationsSequence = Sequence()
 
+
 def add_study_and_series_information(ds: FileDataset, series_data):
-    reference_ds = series_data[0] # All elements in series should have the same data
+    reference_ds = series_data[0]  # All elements in series should have the same data
     ds.StudyDate = reference_ds.StudyDate
     ds.SeriesDate = getattr(reference_ds, 'SeriesDate', '')
     ds.StudyTime = reference_ds.StudyTime
@@ -71,12 +78,13 @@ def add_study_and_series_information(ds: FileDataset, series_data):
     ds.StudyDescription = getattr(reference_ds, 'StudyDescription', '')
     ds.SeriesDescription = getattr(reference_ds, 'SeriesDescription', '')
     ds.StudyInstanceUID = reference_ds.StudyInstanceUID
-    ds.SeriesInstanceUID = generate_uid() # TODO: find out if random generation is ok
+    ds.SeriesInstanceUID = generate_uid()  # TODO: find out if random generation is ok
     ds.StudyID = reference_ds.StudyID
-    ds.SeriesNumber = "1" # TODO: find out if we can just use 1 (Should be fine since its a new series)
+    ds.SeriesNumber = "1"  # TODO: find out if we can just use 1 (Should be fine since its a new series)
+
 
 def add_patient_information(ds: FileDataset, series_data):
-    reference_ds = series_data[0] # All elements in series should have the same data
+    reference_ds = series_data[0]  # All elements in series should have the same data
     ds.PatientName = getattr(reference_ds, 'PatientName', '')
     ds.PatientID = getattr(reference_ds, 'PatientID', '')
     ds.PatientBirthDate = getattr(reference_ds, 'PatientBirthDate', '')
@@ -88,7 +96,7 @@ def add_patient_information(ds: FileDataset, series_data):
 
 def add_refd_frame_of_ref_sequence(ds: FileDataset, series_data):
     refd_frame_of_ref = Dataset()
-    refd_frame_of_ref.FrameOfReferenceUID = generate_uid() # TODO Find out if random generation is ok
+    refd_frame_of_ref.FrameOfReferenceUID = generate_uid()  # TODO Find out if random generation is ok
     refd_frame_of_ref.RTReferencedStudySequence = create_frame_of_ref_study_sequence(series_data)
 
     # Add to sequence
@@ -97,7 +105,7 @@ def add_refd_frame_of_ref_sequence(ds: FileDataset, series_data):
 
 
 def create_frame_of_ref_study_sequence(series_data) -> Sequence:
-    reference_ds = series_data[0] # All elements in series should have the same data
+    reference_ds = series_data[0]  # All elements in series should have the same data
     rt_refd_series = Dataset()
     rt_refd_series.SeriesInstanceUID = reference_ds.SeriesInstanceUID
     rt_refd_series.ContourImageSequence = create_contour_image_sequence(series_data)
@@ -121,9 +129,10 @@ def create_contour_image_sequence(series_data) -> Sequence:
     # Add each referenced image
     for series in series_data:
         contour_image = Dataset()
-        contour_image.ReferencedSOPClassUID = series.file_meta.MediaStorageSOPClassUID
-        contour_image.ReferencedSOPInstanceUID = series.file_meta.MediaStorageSOPInstanceUID
+        contour_image.ReferencedSOPClassUID = series.SOPClassUID
+        contour_image.ReferencedSOPInstanceUID = series.SOPInstanceUID
         contour_image_sequence.append(contour_image)
+
     return contour_image_sequence
 
 
@@ -134,7 +143,7 @@ def create_structure_set_roi(roi_data: ROIData) -> Dataset:
     structure_set_roi.ReferencedFrameOfReferenceUID = roi_data.frame_of_reference_uid
     structure_set_roi.ROIName = roi_data.name
     structure_set_roi.ROIDescription = roi_data.description
-    structure_set_roi.ROIGenerationAlgorithm = 'MANUAL'
+    structure_set_roi.ROIGenerationAlgorithm = roi_data.roi_generation_algorithm
     return structure_set_roi
 
 
@@ -166,8 +175,8 @@ def create_contour_sequence(roi_data: ROIData, series_data) -> Sequence:
 
 def create_contour(series_slice: Dataset, contour_data: np.ndarray) -> Dataset:
     contour_image = Dataset()
-    contour_image.ReferencedSOPClassUID = series_slice.file_meta.MediaStorageSOPClassUID
-    contour_image.ReferencedSOPInstanceUID = series_slice.file_meta.MediaStorageSOPInstanceUID
+    contour_image.ReferencedSOPClassUID = series_slice.SOPClassUID
+    contour_image.ReferencedSOPInstanceUID = series_slice.SOPInstanceUID
 
     # Contour Image Sequence
     contour_image_sequence = Sequence()
@@ -175,7 +184,7 @@ def create_contour(series_slice: Dataset, contour_data: np.ndarray) -> Dataset:
 
     contour = Dataset()
     contour.ContourImageSequence = contour_image_sequence
-    contour.ContourGeometricType = 'CLOSED_PLANAR' # TODO figure out how to get this value
+    contour.ContourGeometricType = 'CLOSED_PLANAR'  # TODO figure out how to get this value
     contour.NumberOfContourPoints = len(contour_data) / 3  # Each point has an x, y, and z value
     contour.ContourData = contour_data
 
